use bevy::{
    app::{App, PluginGroup, Startup, Update},
    diagnostic::FrameTimeDiagnosticsPlugin,
    prelude::IntoSystemConfigs,
    utils::default,
    window::{Window, WindowPlugin, WindowTheme},
    DefaultPlugins,
};
use camera::UserCamera;
use market::Market;
use player::Player;
use ui::{FPSText, FishCounterText, KeybindingsText, MoneyText};
use water::Water;

mod camera;
mod market;
mod player;
mod ui;
mod water;

pub const CHARACTER_SPEED: f32 = 1000.0;
pub const CAMERA_DECAY_RATE: f32 = 3.0;
pub const INTERACTION_AREA_RADIUS: f32 = 100.0;
pub const FISH_PRICE: usize = 15;

pub fn start_game() {
    App::new()
        .add_plugins(DefaultPlugins.set(WindowPlugin {
            primary_window: Some(Window {
                title: "Fisher ~Tahinli".to_owned(),
                // present_mode: PresentMode::Immediate, //Vsync off
                window_theme: Some(WindowTheme::Dark),
                ..default()
            }),
            ..default()
        }))
        .add_plugins(FrameTimeDiagnosticsPlugin)
        .add_systems(
            Startup,
            (
                FPSText::setup,
                UserCamera::setup,
                Water::setup,
                Market::setup,
                Player::setup,
                FishCounterText::setup,
                MoneyText::setup,
                KeybindingsText::setup,
            ),
        )
        .add_systems(
            Update,
            (
                FPSText::update,
                UserCamera::update,
                Player::r#move.before(FishCounterText::update),
                Water::fishing,
                Market::sell.chain().before(MoneyText::update),
                FishCounterText::update,
                MoneyText::update,
            ),
        )
        .run();
}
